==> paraview-v0.2.0.zip: paraview-v0.2.0/ParaView/Widgets/vtkKWXtEmbeddedWidget.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkKWXtEmbeddedWidget.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "vtkKWApplication.h"
#include "vtkKWXtEmbeddedWidget.h"
#include "vtkObjectFactory.h"



//------------------------------------------------------------------------------
vtkKWXtEmbeddedWidget* vtkKWXtEmbeddedWidget::New()
{
  // First try to create the object from the vtkObjectFactory
  vtkObject* ret = vtkObjectFactory::CreateInstance("vtkKWXtEmbeddedWidget");
  if(ret)
    {
    return (vtkKWXtEmbeddedWidget*)ret;
    }
  // If the factory was unable to create the object, then create it here.
  return new vtkKWXtEmbeddedWidget;
}




int vtkKWXtEmbeddedWidgetCommand(ClientData cd, Tcl_Interp *interp,
                             int argc, char *argv[]);

vtkKWXtEmbeddedWidget::vtkKWXtEmbeddedWidget()
{
  this->WindowId = NULL;
}

vtkKWXtEmbeddedWidget::~vtkKWXtEmbeddedWidget()
{

}

void vtkKWXtEmbeddedWidget::Display()
{
  // map the window
  this->Script("wm deiconify %s",this->GetWidgetName());
}


void vtkKWXtEmbeddedWidget::Create(vtkKWApplication *app, char *args)
{
  // must set the application
  if (this->Application)
    {
    vtkErrorMacro("Dialog already created");
    return;
    }

  this->SetApplication(app);

  // create the top level
  const char* wname = this->GetWidgetName();
  if(this->WindowId)
    {
    this->Script("toplevel %s %s -use 0x%x",wname,args, this->WindowId);
    }
  else
    {
    this->Script("toplevel %s %s",wname,args); 
    this->Script("wm withdraw %s",wname);
    }
}

==> paraview-v0.6.0.zip: paraview-v0.6.0/ParaView/Widgets/vtkKWXtEmbeddedWidget.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkKWXtEmbeddedWidget.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "vtkKWApplication.h"
#include "vtkKWXtEmbeddedWidget.h"
#include "vtkObjectFactory.h"



//------------------------------------------------------------------------------
vtkStandardNewMacro(vtkKWXtEmbeddedWidget);
vtkCxxRevisionMacro(vtkKWXtEmbeddedWidget, "1.5");

int vtkKWXtEmbeddedWidgetCommand(ClientData cd, Tcl_Interp *interp,
                             int argc, char *argv[]);

vtkKWXtEmbeddedWidget::vtkKWXtEmbeddedWidget()
{
  this->WindowId = NULL;
}

vtkKWXtEmbeddedWidget::~vtkKWXtEmbeddedWidget()
{

}

void vtkKWXtEmbeddedWidget::Display()
{
  // map the window
  this->Script("wm deiconify %s",this->GetWidgetName());
}


void vtkKWXtEmbeddedWidget::Create(vtkKWApplication *app, char *args)
{
  // must set the application
  if (this->Application)
    {
    vtkErrorMacro("Dialog already created");
    return;
    }

  this->SetApplication(app);

  // create the top level
  const char* wname = this->GetWidgetName();
  if(this->WindowId)
    {
    this->Script("toplevel %s %s -use 0x%x",wname,args, this->WindowId);
    }
  else
    {
    this->Script("toplevel %s %s",wname,args); 
    this->Script("wm withdraw %s",wname);
    }
}

//----------------------------------------------------------------------------
void vtkKWXtEmbeddedWidget::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os,indent);
}
